/***************************************************************************
	file:			tcn75a.h
	product:	API-005
	descr:		Diese API ermoeglicht das Benutzen von 2-Wire (I2C) Temperatur
	Sensor TCN75A. Mit dieser API kann man die Konfiguration von TCN75A vornehmen,
	und die Umgebungstemperatur aus dem Temperature Register auslesen.
	
	Diese API ist mit I2C-003 2-Wire Temperatur Sensor TCN75A kompatibel.
	
	Folgende Voraussetzungen mssen erfllt sein:
			Inkludierung der API-002: Emulator der I2C (TWI) Schnittstelle wird vorausgesetzt.
			Die bertragung der Bytes ber I2C Schnittstelle, darf nicht unterbrochen
			werden, z. B. von einem Interrupt.

	date: 		11.2013 - first release

	version 	1.0
	compiler:	Keil Cx51 V9.05

	mc:				AT89C5131A
	crystal:	24MHz

	author: 	Viktor Schabelski info@approbe.de
	licence:	Creative Commons Lizenz
                http://www.stack2Learn.de/cc.html

**************************************************/


#ifndef _TCN75A_H
	#define _TCN75A_H

/*-----------------------------------------------------------------------------
	includes
---------------------------------------------------*/
#include "tcn75a_config.h"

/*-----------------------------------------------------------------------------
	constans and globals
---------------------------------------------------*/
// Error code fuer EEPROM
typedef enum _errorCodeTCN75A{
	TCN75A_SUCCESS = 0x00,
	TCN75A_BUSY = 0x01,
	TCN75A_WRITE_FAIL = 0x02,
	TCN75A_READ_FAIL = 0x03
}errorCodeTCN75A_t;


/*-----------------------------------------------------------------------------
	api
---------------------------------------------------*/
// Initialisierung von TCN75A
errorCodeTCN75A_t TCN75A_Init (void);

// Tempertur lesen
errorCodeTCN75A_t TCN75A_GetTemp (float* temperature);




#endif